@@ -823,8 +823,9 @@ incLocalSrcInfo <- function(vn, w) {
     new <- list(srcfile = if (is.null(w$srcfile)) NA_character_ else w$srcfile,
                 frow = if (is.null(w$frow)) NA_integer_ else w$frow,
                 lrow = if (is.null(w$lrow)) NA_integer_ else w$lrow)
+    new <- as.data.frame(new, stringsAsFactors = FALSE)
     if (is.null(value))
-        value <- as.data.frame(new, stringsAsFactors = FALSE)
+        value <- new
     else
         value <- rbind(value, new)
     assign("srcinfo", value, entry)
@@ -968,21 +969,26 @@ checkUsage <- function(fun, name = "<anonymous>",
         oldOpts <- options(warnPartialMatchArgs = TRUE)
         on.exit(options(oldOpts))
     }
-    collectUsage(fun, name = name,
-                 warn = report,
-                 suppressLocal = suppressLocal,
-                 suppressParamAssigns = suppressParamAssigns,
-                 suppressParamUnused = suppressParamUnused,
-                 suppressFundefMismatch = suppressFundefMismatch,
-                 suppressLocalUnused = suppressLocalUnused,
-                 suppressNoLocalFun = suppressNoLocalFun,
-                 skipWith = skipWith,
-                 enterGlobal = checkUsageEnterGlobal,
-                 enterLocal = checkUsageEnterLocal,
-                 startCollectLocals = checkUsageStartLocals,
-                 finishCollectLocals = checkUsageFinishLocals,
-                 suppressUndefined = suppressUndefined,
-                 suppressPartialMatchArgs = suppressPartialMatchArgs)
+    tryCatch(collectUsage(fun, name = name,
+                          warn = report,
+                          suppressLocal = suppressLocal,
+                          suppressParamAssigns = suppressParamAssigns,
+                          suppressParamUnused = suppressParamUnused,
+                          suppressFundefMismatch = suppressFundefMismatch,
+                          suppressLocalUnused = suppressLocalUnused,
+                          suppressNoLocalFun = suppressNoLocalFun,
+                          skipWith = skipWith,
+                          enterGlobal = checkUsageEnterGlobal,
+                          enterLocal = checkUsageEnterLocal,
+                          startCollectLocals = checkUsageStartLocals,
+                          finishCollectLocals = checkUsageFinishLocals,
+                          suppressUndefined = suppressUndefined,
+                          suppressPartialMatchArgs = suppressPartialMatchArgs),
+             error = function(e) {
+                         report(paste0(name, ": Error while checking: ",
+                                       conditionMessage(e), "\n"))
+                     })
+    invisible(NULL)         
 }
 
 checkUsageEnv <- function(env, ...) {
